# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddressRateLimiting(object):
    """
    The IP rate limiting configuration. Defines the amount of allowed requests from a unique IP address and the resulting block response code when that threshold is exceeded.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AddressRateLimiting object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_enabled:
            The value to assign to the is_enabled property of this AddressRateLimiting.
        :type is_enabled: bool

        :param allowed_rate_per_address:
            The value to assign to the allowed_rate_per_address property of this AddressRateLimiting.
        :type allowed_rate_per_address: int

        :param max_delayed_count_per_address:
            The value to assign to the max_delayed_count_per_address property of this AddressRateLimiting.
        :type max_delayed_count_per_address: int

        :param block_response_code:
            The value to assign to the block_response_code property of this AddressRateLimiting.
        :type block_response_code: int

        """
        self.swagger_types = {
            'is_enabled': 'bool',
            'allowed_rate_per_address': 'int',
            'max_delayed_count_per_address': 'int',
            'block_response_code': 'int'
        }

        self.attribute_map = {
            'is_enabled': 'isEnabled',
            'allowed_rate_per_address': 'allowedRatePerAddress',
            'max_delayed_count_per_address': 'maxDelayedCountPerAddress',
            'block_response_code': 'blockResponseCode'
        }

        self._is_enabled = None
        self._allowed_rate_per_address = None
        self._max_delayed_count_per_address = None
        self._block_response_code = None

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this AddressRateLimiting.
        Enables or disables the address rate limiting Web Application Firewall feature.


        :return: The is_enabled of this AddressRateLimiting.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this AddressRateLimiting.
        Enables or disables the address rate limiting Web Application Firewall feature.


        :param is_enabled: The is_enabled of this AddressRateLimiting.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def allowed_rate_per_address(self):
        """
        Gets the allowed_rate_per_address of this AddressRateLimiting.
        The number of allowed requests per second from one IP address. If unspecified, defaults to `1`.


        :return: The allowed_rate_per_address of this AddressRateLimiting.
        :rtype: int
        """
        return self._allowed_rate_per_address

    @allowed_rate_per_address.setter
    def allowed_rate_per_address(self, allowed_rate_per_address):
        """
        Sets the allowed_rate_per_address of this AddressRateLimiting.
        The number of allowed requests per second from one IP address. If unspecified, defaults to `1`.


        :param allowed_rate_per_address: The allowed_rate_per_address of this AddressRateLimiting.
        :type: int
        """
        self._allowed_rate_per_address = allowed_rate_per_address

    @property
    def max_delayed_count_per_address(self):
        """
        Gets the max_delayed_count_per_address of this AddressRateLimiting.
        The maximum number of requests allowed to be queued before subsequent requests are dropped. If unspecified, defaults to `10`.


        :return: The max_delayed_count_per_address of this AddressRateLimiting.
        :rtype: int
        """
        return self._max_delayed_count_per_address

    @max_delayed_count_per_address.setter
    def max_delayed_count_per_address(self, max_delayed_count_per_address):
        """
        Sets the max_delayed_count_per_address of this AddressRateLimiting.
        The maximum number of requests allowed to be queued before subsequent requests are dropped. If unspecified, defaults to `10`.


        :param max_delayed_count_per_address: The max_delayed_count_per_address of this AddressRateLimiting.
        :type: int
        """
        self._max_delayed_count_per_address = max_delayed_count_per_address

    @property
    def block_response_code(self):
        """
        Gets the block_response_code of this AddressRateLimiting.
        The response status code returned when a request is blocked. If unspecified, defaults to `503`. The list of available response codes: `400`, `401`, `403`, `404`, `405`, `408`, `409`, `411`, `412`, `413`, `414`, `415`, `416`, `422`, `494`, `495`, `496`, `497`, `499`, `500`, `501`, `502`, `503`, `504`, `507`.


        :return: The block_response_code of this AddressRateLimiting.
        :rtype: int
        """
        return self._block_response_code

    @block_response_code.setter
    def block_response_code(self, block_response_code):
        """
        Sets the block_response_code of this AddressRateLimiting.
        The response status code returned when a request is blocked. If unspecified, defaults to `503`. The list of available response codes: `400`, `401`, `403`, `404`, `405`, `408`, `409`, `411`, `412`, `413`, `414`, `415`, `416`, `422`, `494`, `495`, `496`, `497`, `499`, `500`, `501`, `502`, `503`, `504`, `507`.


        :param block_response_code: The block_response_code of this AddressRateLimiting.
        :type: int
        """
        self._block_response_code = block_response_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificatePublicKeyInfo(object):
    """
    Information about the public key and the algorithm used by the public key.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificatePublicKeyInfo object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param algorithm:
            The value to assign to the algorithm property of this CertificatePublicKeyInfo.
        :type algorithm: str

        :param exponent:
            The value to assign to the exponent property of this CertificatePublicKeyInfo.
        :type exponent: int

        :param key_size:
            The value to assign to the key_size property of this CertificatePublicKeyInfo.
        :type key_size: int

        """
        self.swagger_types = {
            'algorithm': 'str',
            'exponent': 'int',
            'key_size': 'int'
        }

        self.attribute_map = {
            'algorithm': 'algorithm',
            'exponent': 'exponent',
            'key_size': 'keySize'
        }

        self._algorithm = None
        self._exponent = None
        self._key_size = None

    @property
    def algorithm(self):
        """
        Gets the algorithm of this CertificatePublicKeyInfo.
        The algorithm identifier and parameters for the public key.


        :return: The algorithm of this CertificatePublicKeyInfo.
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """
        Sets the algorithm of this CertificatePublicKeyInfo.
        The algorithm identifier and parameters for the public key.


        :param algorithm: The algorithm of this CertificatePublicKeyInfo.
        :type: str
        """
        self._algorithm = algorithm

    @property
    def exponent(self):
        """
        Gets the exponent of this CertificatePublicKeyInfo.
        The private key exponent.


        :return: The exponent of this CertificatePublicKeyInfo.
        :rtype: int
        """
        return self._exponent

    @exponent.setter
    def exponent(self, exponent):
        """
        Sets the exponent of this CertificatePublicKeyInfo.
        The private key exponent.


        :param exponent: The exponent of this CertificatePublicKeyInfo.
        :type: int
        """
        self._exponent = exponent

    @property
    def key_size(self):
        """
        Gets the key_size of this CertificatePublicKeyInfo.
        The number of bits in a key used by a cryptographic algorithm.


        :return: The key_size of this CertificatePublicKeyInfo.
        :rtype: int
        """
        return self._key_size

    @key_size.setter
    def key_size(self, key_size):
        """
        Sets the key_size of this CertificatePublicKeyInfo.
        The number of bits in a key used by a cryptographic algorithm.


        :param key_size: The key_size of this CertificatePublicKeyInfo.
        :type: int
        """
        self._key_size = key_size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_publication_package import CreatePublicationPackage
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateImagePublicationPackage(CreatePublicationPackage):
    """
    An object for creating an image publication package.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateImagePublicationPackage object with values from keyword arguments. The default value of the :py:attr:`~oci.marketplace.models.CreateImagePublicationPackage.package_type` attribute
        of this class is ``IMAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param package_version:
            The value to assign to the package_version property of this CreateImagePublicationPackage.
        :type package_version: str

        :param package_type:
            The value to assign to the package_type property of this CreateImagePublicationPackage.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE"
        :type package_type: str

        :param operating_system:
            The value to assign to the operating_system property of this CreateImagePublicationPackage.
        :type operating_system: oci.marketplace.models.OperatingSystem

        :param eula:
            The value to assign to the eula property of this CreateImagePublicationPackage.
        :type eula: list[oci.marketplace.models.Eula]

        :param image_id:
            The value to assign to the image_id property of this CreateImagePublicationPackage.
        :type image_id: str

        """
        self.swagger_types = {
            'package_version': 'str',
            'package_type': 'str',
            'operating_system': 'OperatingSystem',
            'eula': 'list[Eula]',
            'image_id': 'str'
        }

        self.attribute_map = {
            'package_version': 'packageVersion',
            'package_type': 'packageType',
            'operating_system': 'operatingSystem',
            'eula': 'eula',
            'image_id': 'imageId'
        }

        self._package_version = None
        self._package_type = None
        self._operating_system = None
        self._eula = None
        self._image_id = None
        self._package_type = 'IMAGE'

    @property
    def image_id(self):
        """
        Gets the image_id of this CreateImagePublicationPackage.
        The unique identifier for the base image of the publication.


        :return: The image_id of this CreateImagePublicationPackage.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this CreateImagePublicationPackage.
        The unique identifier for the base image of the publication.


        :param image_id: The image_id of this CreateImagePublicationPackage.
        :type: str
        """
        self._image_id = image_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDbHomeBase(object):
    """
    Details for creating a Database Home.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "NONE"
    SOURCE_NONE = "NONE"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "DB_BACKUP"
    SOURCE_DB_BACKUP = "DB_BACKUP"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "DATABASE"
    SOURCE_DATABASE = "DATABASE"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "VM_CLUSTER_BACKUP"
    SOURCE_VM_CLUSTER_BACKUP = "VM_CLUSTER_BACKUP"

    #: A constant which can be used with the source property of a CreateDbHomeBase.
    #: This constant has a value of "VM_CLUSTER_NEW"
    SOURCE_VM_CLUSTER_NEW = "VM_CLUSTER_NEW"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDbHomeBase object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.CreateDbHomeWithDbSystemIdFromDatabaseDetails`
        * :class:`~oci.database.models.CreateDbHomeWithDbSystemIdFromBackupDetails`
        * :class:`~oci.database.models.CreateDbHomeWithVmClusterIdFromBackupDetails`
        * :class:`~oci.database.models.CreateDbHomeWithDbSystemIdDetails`
        * :class:`~oci.database.models.CreateDbHomeWithVmClusterIdDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDbHomeBase.
        :type display_name: str

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CreateDbHomeBase.
        :type kms_key_id: str

        :param kms_key_version_id:
            The value to assign to the kms_key_version_id property of this CreateDbHomeBase.
        :type kms_key_version_id: str

        :param database_software_image_id:
            The value to assign to the database_software_image_id property of this CreateDbHomeBase.
        :type database_software_image_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDbHomeBase.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDbHomeBase.
        :type defined_tags: dict(str, dict(str, object))

        :param source:
            The value to assign to the source property of this CreateDbHomeBase.
            Allowed values for this property are: "NONE", "DB_BACKUP", "DATABASE", "VM_CLUSTER_BACKUP", "VM_CLUSTER_NEW"
        :type source: str

        :param is_desupported_version:
            The value to assign to the is_desupported_version property of this CreateDbHomeBase.
        :type is_desupported_version: bool

        """
        self.swagger_types = {
            'display_name': 'str',
            'kms_key_id': 'str',
            'kms_key_version_id': 'str',
            'database_software_image_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'source': 'str',
            'is_desupported_version': 'bool'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'kms_key_id': 'kmsKeyId',
            'kms_key_version_id': 'kmsKeyVersionId',
            'database_software_image_id': 'databaseSoftwareImageId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'source': 'source',
            'is_desupported_version': 'isDesupportedVersion'
        }

        self._display_name = None
        self._kms_key_id = None
        self._kms_key_version_id = None
        self._database_software_image_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._source = None
        self._is_desupported_version = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['source']

        if type == 'DATABASE':
            return 'CreateDbHomeWithDbSystemIdFromDatabaseDetails'

        if type == 'DB_BACKUP':
            return 'CreateDbHomeWithDbSystemIdFromBackupDetails'

        if type == 'VM_CLUSTER_BACKUP':
            return 'CreateDbHomeWithVmClusterIdFromBackupDetails'

        if type == 'NONE':
            return 'CreateDbHomeWithDbSystemIdDetails'

        if type == 'VM_CLUSTER_NEW':
            return 'CreateDbHomeWithVmClusterIdDetails'
        else:
            return 'CreateDbHomeBase'

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDbHomeBase.
        The user-provided name of the Database Home.


        :return: The display_name of this CreateDbHomeBase.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDbHomeBase.
        The user-provided name of the Database Home.


        :param display_name: The display_name of this CreateDbHomeBase.
        :type: str
        """
        self._display_name = display_name

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this CreateDbHomeBase.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :return: The kms_key_id of this CreateDbHomeBase.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this CreateDbHomeBase.
        The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.


        :param kms_key_id: The kms_key_id of this CreateDbHomeBase.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def kms_key_version_id(self):
        """
        Gets the kms_key_version_id of this CreateDbHomeBase.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :return: The kms_key_version_id of this CreateDbHomeBase.
        :rtype: str
        """
        return self._kms_key_version_id

    @kms_key_version_id.setter
    def kms_key_version_id(self, kms_key_version_id):
        """
        Sets the kms_key_version_id of this CreateDbHomeBase.
        The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions. If none is specified, the current key version (latest) of the Key Id is used for the operation.


        :param kms_key_version_id: The kms_key_version_id of this CreateDbHomeBase.
        :type: str
        """
        self._kms_key_version_id = kms_key_version_id

    @property
    def database_software_image_id(self):
        """
        Gets the database_software_image_id of this CreateDbHomeBase.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The database_software_image_id of this CreateDbHomeBase.
        :rtype: str
        """
        return self._database_software_image_id

    @database_software_image_id.setter
    def database_software_image_id(self, database_software_image_id):
        """
        Sets the database_software_image_id of this CreateDbHomeBase.
        The database software image `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param database_software_image_id: The database_software_image_id of this CreateDbHomeBase.
        :type: str
        """
        self._database_software_image_id = database_software_image_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDbHomeBase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDbHomeBase.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDbHomeBase.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDbHomeBase.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDbHomeBase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDbHomeBase.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDbHomeBase.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDbHomeBase.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def source(self):
        """
        Gets the source of this CreateDbHomeBase.
        The source of database: NONE for creating a new database. DB_BACKUP for creating a new database by restoring from a database backup.

        Allowed values for this property are: "NONE", "DB_BACKUP", "DATABASE", "VM_CLUSTER_BACKUP", "VM_CLUSTER_NEW"


        :return: The source of this CreateDbHomeBase.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this CreateDbHomeBase.
        The source of database: NONE for creating a new database. DB_BACKUP for creating a new database by restoring from a database backup.


        :param source: The source of this CreateDbHomeBase.
        :type: str
        """
        allowed_values = ["NONE", "DB_BACKUP", "DATABASE", "VM_CLUSTER_BACKUP", "VM_CLUSTER_NEW"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            raise ValueError(
                "Invalid value for `source`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._source = source

    @property
    def is_desupported_version(self):
        """
        Gets the is_desupported_version of this CreateDbHomeBase.
        If true, the customer acknowledges that the specified Oracle Database software is an older release that is not currently supported by OCI.


        :return: The is_desupported_version of this CreateDbHomeBase.
        :rtype: bool
        """
        return self._is_desupported_version

    @is_desupported_version.setter
    def is_desupported_version(self, is_desupported_version):
        """
        Sets the is_desupported_version of this CreateDbHomeBase.
        If true, the customer acknowledges that the specified Oracle Database software is an older release that is not currently supported by OCI.


        :param is_desupported_version: The is_desupported_version of this CreateDbHomeBase.
        :type: bool
        """
        self._is_desupported_version = is_desupported_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DerivedLogicalEntities(object):
    """
    Entities derived from the application of a pattern to a list of file paths.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DerivedLogicalEntities object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this DerivedLogicalEntities.
        :type name: str

        :param realized_expression:
            The value to assign to the realized_expression property of this DerivedLogicalEntities.
        :type realized_expression: str

        :param files_in_logical_grouping:
            The value to assign to the files_in_logical_grouping property of this DerivedLogicalEntities.
        :type files_in_logical_grouping: list[str]

        """
        self.swagger_types = {
            'name': 'str',
            'realized_expression': 'str',
            'files_in_logical_grouping': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'realized_expression': 'realizedExpression',
            'files_in_logical_grouping': 'filesInLogicalGrouping'
        }

        self._name = None
        self._realized_expression = None
        self._files_in_logical_grouping = None

    @property
    def name(self):
        """
        Gets the name of this DerivedLogicalEntities.
        The name of the derived logical entity. The group name of the unmatched files will be UNMATCHED


        :return: The name of this DerivedLogicalEntities.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DerivedLogicalEntities.
        The name of the derived logical entity. The group name of the unmatched files will be UNMATCHED


        :param name: The name of this DerivedLogicalEntities.
        :type: str
        """
        self._name = name

    @property
    def realized_expression(self):
        """
        Gets the realized_expression of this DerivedLogicalEntities.
        The expression realized after resolving qualifiers . Used in deriving this logical entity


        :return: The realized_expression of this DerivedLogicalEntities.
        :rtype: str
        """
        return self._realized_expression

    @realized_expression.setter
    def realized_expression(self, realized_expression):
        """
        Sets the realized_expression of this DerivedLogicalEntities.
        The expression realized after resolving qualifiers . Used in deriving this logical entity


        :param realized_expression: The realized_expression of this DerivedLogicalEntities.
        :type: str
        """
        self._realized_expression = realized_expression

    @property
    def files_in_logical_grouping(self):
        """
        Gets the files_in_logical_grouping of this DerivedLogicalEntities.
        The list of file paths that belong to the grouping of logical entity or UNMATCHED for which realizedExpression is a selector.


        :return: The files_in_logical_grouping of this DerivedLogicalEntities.
        :rtype: list[str]
        """
        return self._files_in_logical_grouping

    @files_in_logical_grouping.setter
    def files_in_logical_grouping(self, files_in_logical_grouping):
        """
        Sets the files_in_logical_grouping of this DerivedLogicalEntities.
        The list of file paths that belong to the grouping of logical entity or UNMATCHED for which realizedExpression is a selector.


        :param files_in_logical_grouping: The files_in_logical_grouping of this DerivedLogicalEntities.
        :type: list[str]
        """
        self._files_in_logical_grouping = files_in_logical_grouping

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StreamPool(object):
    """
    The details of a stream pool.
    """

    #: A constant which can be used with the lifecycle_state property of a StreamPool.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a StreamPool.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a StreamPool.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a StreamPool.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a StreamPool.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a StreamPool.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new StreamPool object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this StreamPool.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this StreamPool.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this StreamPool.
        :type name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this StreamPool.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this StreamPool.
        :type lifecycle_state_details: str

        :param time_created:
            The value to assign to the time_created property of this StreamPool.
        :type time_created: datetime

        :param kafka_settings:
            The value to assign to the kafka_settings property of this StreamPool.
        :type kafka_settings: oci.streaming.models.KafkaSettings

        :param custom_encryption_key:
            The value to assign to the custom_encryption_key property of this StreamPool.
        :type custom_encryption_key: oci.streaming.models.CustomEncryptionKey

        :param is_private:
            The value to assign to the is_private property of this StreamPool.
        :type is_private: bool

        :param endpoint_fqdn:
            The value to assign to the endpoint_fqdn property of this StreamPool.
        :type endpoint_fqdn: str

        :param private_endpoint_settings:
            The value to assign to the private_endpoint_settings property of this StreamPool.
        :type private_endpoint_settings: oci.streaming.models.PrivateEndpointSettings

        :param freeform_tags:
            The value to assign to the freeform_tags property of this StreamPool.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this StreamPool.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'time_created': 'datetime',
            'kafka_settings': 'KafkaSettings',
            'custom_encryption_key': 'CustomEncryptionKey',
            'is_private': 'bool',
            'endpoint_fqdn': 'str',
            'private_endpoint_settings': 'PrivateEndpointSettings',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'time_created': 'timeCreated',
            'kafka_settings': 'kafkaSettings',
            'custom_encryption_key': 'customEncryptionKey',
            'is_private': 'isPrivate',
            'endpoint_fqdn': 'endpointFqdn',
            'private_endpoint_settings': 'privateEndpointSettings',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._name = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._time_created = None
        self._kafka_settings = None
        self._custom_encryption_key = None
        self._is_private = None
        self._endpoint_fqdn = None
        self._private_endpoint_settings = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this StreamPool.
        The OCID of the stream pool.


        :return: The id of this StreamPool.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this StreamPool.
        The OCID of the stream pool.


        :param id: The id of this StreamPool.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this StreamPool.
        Compartment OCID that the pool belongs to.


        :return: The compartment_id of this StreamPool.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this StreamPool.
        Compartment OCID that the pool belongs to.


        :param compartment_id: The compartment_id of this StreamPool.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this StreamPool.
        The name of the stream pool.


        :return: The name of this StreamPool.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this StreamPool.
        The name of the stream pool.


        :param name: The name of this StreamPool.
        :type: str
        """
        self._name = name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this StreamPool.
        The current state of the stream pool.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this StreamPool.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this StreamPool.
        The current state of the stream pool.


        :param lifecycle_state: The lifecycle_state of this StreamPool.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this StreamPool.
        Any additional details about the current state of the stream.


        :return: The lifecycle_state_details of this StreamPool.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this StreamPool.
        Any additional details about the current state of the stream.


        :param lifecycle_state_details: The lifecycle_state_details of this StreamPool.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this StreamPool.
        The date and time the stream pool was created, expressed in in `RFC 3339`__ timestamp format.

        Example: `2018-04-20T00:00:07.405Z`

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this StreamPool.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this StreamPool.
        The date and time the stream pool was created, expressed in in `RFC 3339`__ timestamp format.

        Example: `2018-04-20T00:00:07.405Z`

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this StreamPool.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def kafka_settings(self):
        """
        **[Required]** Gets the kafka_settings of this StreamPool.

        :return: The kafka_settings of this StreamPool.
        :rtype: oci.streaming.models.KafkaSettings
        """
        return self._kafka_settings

    @kafka_settings.setter
    def kafka_settings(self, kafka_settings):
        """
        Sets the kafka_settings of this StreamPool.

        :param kafka_settings: The kafka_settings of this StreamPool.
        :type: oci.streaming.models.KafkaSettings
        """
        self._kafka_settings = kafka_settings

    @property
    def custom_encryption_key(self):
        """
        **[Required]** Gets the custom_encryption_key of this StreamPool.

        :return: The custom_encryption_key of this StreamPool.
        :rtype: oci.streaming.models.CustomEncryptionKey
        """
        return self._custom_encryption_key

    @custom_encryption_key.setter
    def custom_encryption_key(self, custom_encryption_key):
        """
        Sets the custom_encryption_key of this StreamPool.

        :param custom_encryption_key: The custom_encryption_key of this StreamPool.
        :type: oci.streaming.models.CustomEncryptionKey
        """
        self._custom_encryption_key = custom_encryption_key

    @property
    def is_private(self):
        """
        Gets the is_private of this StreamPool.
        True if the stream pool is private, false otherwise.
        If the stream pool is private, the streams inside the stream pool can only be accessed from inside the associated subnetId.


        :return: The is_private of this StreamPool.
        :rtype: bool
        """
        return self._is_private

    @is_private.setter
    def is_private(self, is_private):
        """
        Sets the is_private of this StreamPool.
        True if the stream pool is private, false otherwise.
        If the stream pool is private, the streams inside the stream pool can only be accessed from inside the associated subnetId.


        :param is_private: The is_private of this StreamPool.
        :type: bool
        """
        self._is_private = is_private

    @property
    def endpoint_fqdn(self):
        """
        Gets the endpoint_fqdn of this StreamPool.
        The FQDN used to access the streams inside the stream pool (same FQDN as the messagesEndpoint attribute of a :class:`Stream` object).
        If the stream pool is private, the FQDN is customized and can only be accessed from inside the associated subnetId, otherwise the FQDN is publicly resolvable.
        Depending on which protocol you attempt to use, you need to either prepend https or append the Kafka port.


        :return: The endpoint_fqdn of this StreamPool.
        :rtype: str
        """
        return self._endpoint_fqdn

    @endpoint_fqdn.setter
    def endpoint_fqdn(self, endpoint_fqdn):
        """
        Sets the endpoint_fqdn of this StreamPool.
        The FQDN used to access the streams inside the stream pool (same FQDN as the messagesEndpoint attribute of a :class:`Stream` object).
        If the stream pool is private, the FQDN is customized and can only be accessed from inside the associated subnetId, otherwise the FQDN is publicly resolvable.
        Depending on which protocol you attempt to use, you need to either prepend https or append the Kafka port.


        :param endpoint_fqdn: The endpoint_fqdn of this StreamPool.
        :type: str
        """
        self._endpoint_fqdn = endpoint_fqdn

    @property
    def private_endpoint_settings(self):
        """
        Gets the private_endpoint_settings of this StreamPool.

        :return: The private_endpoint_settings of this StreamPool.
        :rtype: oci.streaming.models.PrivateEndpointSettings
        """
        return self._private_endpoint_settings

    @private_endpoint_settings.setter
    def private_endpoint_settings(self, private_endpoint_settings):
        """
        Sets the private_endpoint_settings of this StreamPool.

        :param private_endpoint_settings: The private_endpoint_settings of this StreamPool.
        :type: oci.streaming.models.PrivateEndpointSettings
        """
        self._private_endpoint_settings = private_endpoint_settings

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this StreamPool.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Exists for cross-compatibility only.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this StreamPool.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this StreamPool.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Exists for cross-compatibility only.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this StreamPool.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this StreamPool.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}'

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this StreamPool.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this StreamPool.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}'

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this StreamPool.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseCredentials(object):
    """
    The database credentials used to perform management activity.
    """

    #: A constant which can be used with the role property of a DatabaseCredentials.
    #: This constant has a value of "NORMAL"
    ROLE_NORMAL = "NORMAL"

    #: A constant which can be used with the role property of a DatabaseCredentials.
    #: This constant has a value of "SYSDBA"
    ROLE_SYSDBA = "SYSDBA"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseCredentials object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param user_name:
            The value to assign to the user_name property of this DatabaseCredentials.
        :type user_name: str

        :param password:
            The value to assign to the password property of this DatabaseCredentials.
        :type password: str

        :param secret_id:
            The value to assign to the secret_id property of this DatabaseCredentials.
        :type secret_id: str

        :param role:
            The value to assign to the role property of this DatabaseCredentials.
            Allowed values for this property are: "NORMAL", "SYSDBA"
        :type role: str

        """
        self.swagger_types = {
            'user_name': 'str',
            'password': 'str',
            'secret_id': 'str',
            'role': 'str'
        }

        self.attribute_map = {
            'user_name': 'userName',
            'password': 'password',
            'secret_id': 'secretId',
            'role': 'role'
        }

        self._user_name = None
        self._password = None
        self._secret_id = None
        self._role = None

    @property
    def user_name(self):
        """
        Gets the user_name of this DatabaseCredentials.
        The database user name used to perform management activity.


        :return: The user_name of this DatabaseCredentials.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this DatabaseCredentials.
        The database user name used to perform management activity.


        :param user_name: The user_name of this DatabaseCredentials.
        :type: str
        """
        self._user_name = user_name

    @property
    def password(self):
        """
        Gets the password of this DatabaseCredentials.
        The password for the database user name.


        :return: The password of this DatabaseCredentials.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this DatabaseCredentials.
        The password for the database user name.


        :param password: The password of this DatabaseCredentials.
        :type: str
        """
        self._password = password

    @property
    def secret_id(self):
        """
        Gets the secret_id of this DatabaseCredentials.
        The `OCID`__ of the secret containing the user password.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The secret_id of this DatabaseCredentials.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """
        Sets the secret_id of this DatabaseCredentials.
        The `OCID`__ of the secret containing the user password.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param secret_id: The secret_id of this DatabaseCredentials.
        :type: str
        """
        self._secret_id = secret_id

    @property
    def role(self):
        """
        Gets the role of this DatabaseCredentials.
        The role of the database user. Indicates whether the database user is a normal user or sysdba.

        Allowed values for this property are: "NORMAL", "SYSDBA"


        :return: The role of this DatabaseCredentials.
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """
        Sets the role of this DatabaseCredentials.
        The role of the database user. Indicates whether the database user is a normal user or sysdba.


        :param role: The role of this DatabaseCredentials.
        :type: str
        """
        allowed_values = ["NORMAL", "SYSDBA"]
        if not value_allowed_none_or_none_sentinel(role, allowed_values):
            raise ValueError(
                "Invalid value for `role`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._role = role

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from oci._vendor import six


def get_tenancy_id_from_certificate(cert):
    if not cert:
        raise RuntimeError('A certificate must be provided')

    for name_attribute in cert.subject:
        val = name_attribute.value
        if val.startswith('opc-tenant:'):
            return val[len('opc-tenant:'):]
        if val.startswith('opc-identity:'):
            return val[len('opc-identity:'):]

    raise RuntimeError('The certificate does not contain a tenancy OCID')


def sanitize_certificate_string(cert_string):
    if six.PY3:
        string_to_replace = cert_string.decode('ascii')
    else:
        string_to_replace = cert_string

    return string_to_replace \
        .replace('-----BEGIN CERTIFICATE-----', '') \
        .replace('-----END CERTIFICATE-----', '') \
        .replace('-----BEGIN PUBLIC KEY-----', '') \
        .replace('-----END PUBLIC KEY-----', '') \
        .replace('\n', '')



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Job(object):
    """
    The properties that define a job. Jobs perform the actions that are defined in your configuration.
    - **Plan job**. A plan job takes your Terraform configuration, parses it, and creates an execution plan.
    - **Apply job**. The apply job takes your execution plan, applies it to the associated stack, then executes
    the configuration's instructions.
    - **Destroy job**. To clean up the infrastructure controlled by the stack, you run a destroy job.
    A destroy job does not delete the stack or associated job resources,
    but instead releases the resources managed by the stack.
    - **Import_TF_State job**. An import Terraform state job takes a Terraform state file and sets it as the current
    state of the stack. This is used to migrate local Terraform environments to Resource Manager.
    """

    #: A constant which can be used with the operation property of a Job.
    #: This constant has a value of "PLAN"
    OPERATION_PLAN = "PLAN"

    #: A constant which can be used with the operation property of a Job.
    #: This constant has a value of "APPLY"
    OPERATION_APPLY = "APPLY"

    #: A constant which can be used with the operation property of a Job.
    #: This constant has a value of "DESTROY"
    OPERATION_DESTROY = "DESTROY"

    #: A constant which can be used with the operation property of a Job.
    #: This constant has a value of "IMPORT_TF_STATE"
    OPERATION_IMPORT_TF_STATE = "IMPORT_TF_STATE"

    #: A constant which can be used with the lifecycle_state property of a Job.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a Job.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a Job.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Job.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a Job.
    #: This constant has a value of "CANCELING"
    LIFECYCLE_STATE_CANCELING = "CANCELING"

    #: A constant which can be used with the lifecycle_state property of a Job.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new Job object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Job.
        :type id: str

        :param stack_id:
            The value to assign to the stack_id property of this Job.
        :type stack_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Job.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this Job.
        :type display_name: str

        :param operation:
            The value to assign to the operation property of this Job.
            Allowed values for this property are: "PLAN", "APPLY", "DESTROY", "IMPORT_TF_STATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation: str

        :param job_operation_details:
            The value to assign to the job_operation_details property of this Job.
        :type job_operation_details: oci.resource_manager.models.JobOperationDetails

        :param apply_job_plan_resolution:
            The value to assign to the apply_job_plan_resolution property of this Job.
        :type apply_job_plan_resolution: oci.resource_manager.models.ApplyJobPlanResolution

        :param resolved_plan_job_id:
            The value to assign to the resolved_plan_job_id property of this Job.
        :type resolved_plan_job_id: str

        :param time_created:
            The value to assign to the time_created property of this Job.
        :type time_created: datetime

        :param time_finished:
            The value to assign to the time_finished property of this Job.
        :type time_finished: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Job.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param failure_details:
            The value to assign to the failure_details property of this Job.
        :type failure_details: oci.resource_manager.models.FailureDetails

        :param cancellation_details:
            The value to assign to the cancellation_details property of this Job.
        :type cancellation_details: oci.resource_manager.models.CancellationDetails

        :param working_directory:
            The value to assign to the working_directory property of this Job.
        :type working_directory: str

        :param variables:
            The value to assign to the variables property of this Job.
        :type variables: dict(str, str)

        :param config_source:
            The value to assign to the config_source property of this Job.
        :type config_source: oci.resource_manager.models.ConfigSourceRecord

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Job.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Job.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'stack_id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'operation': 'str',
            'job_operation_details': 'JobOperationDetails',
            'apply_job_plan_resolution': 'ApplyJobPlanResolution',
            'resolved_plan_job_id': 'str',
            'time_created': 'datetime',
            'time_finished': 'datetime',
            'lifecycle_state': 'str',
            'failure_details': 'FailureDetails',
            'cancellation_details': 'CancellationDetails',
            'working_directory': 'str',
            'variables': 'dict(str, str)',
            'config_source': 'ConfigSourceRecord',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'stack_id': 'stackId',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'operation': 'operation',
            'job_operation_details': 'jobOperationDetails',
            'apply_job_plan_resolution': 'applyJobPlanResolution',
            'resolved_plan_job_id': 'resolvedPlanJobId',
            'time_created': 'timeCreated',
            'time_finished': 'timeFinished',
            'lifecycle_state': 'lifecycleState',
            'failure_details': 'failureDetails',
            'cancellation_details': 'cancellationDetails',
            'working_directory': 'workingDirectory',
            'variables': 'variables',
            'config_source': 'configSource',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._stack_id = None
        self._compartment_id = None
        self._display_name = None
        self._operation = None
        self._job_operation_details = None
        self._apply_job_plan_resolution = None
        self._resolved_plan_job_id = None
        self._time_created = None
        self._time_finished = None
        self._lifecycle_state = None
        self._failure_details = None
        self._cancellation_details = None
        self._working_directory = None
        self._variables = None
        self._config_source = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        Gets the id of this Job.
        The `OCID`__ of the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Job.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Job.
        The `OCID`__ of the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Job.
        :type: str
        """
        self._id = id

    @property
    def stack_id(self):
        """
        Gets the stack_id of this Job.
        The `OCID`__ of the stack that is associated with the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The stack_id of this Job.
        :rtype: str
        """
        return self._stack_id

    @stack_id.setter
    def stack_id(self, stack_id):
        """
        Sets the stack_id of this Job.
        The `OCID`__ of the stack that is associated with the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param stack_id: The stack_id of this Job.
        :type: str
        """
        self._stack_id = stack_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Job.
        The `OCID`__ of the compartment in which the job's associated stack resides.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Job.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Job.
        The `OCID`__ of the compartment in which the job's associated stack resides.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Job.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this Job.
        The job's display name.


        :return: The display_name of this Job.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Job.
        The job's display name.


        :param display_name: The display_name of this Job.
        :type: str
        """
        self._display_name = display_name

    @property
    def operation(self):
        """
        Gets the operation of this Job.
        The type of job executing.

        Allowed values for this property are: "PLAN", "APPLY", "DESTROY", "IMPORT_TF_STATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation of this Job.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this Job.
        The type of job executing.


        :param operation: The operation of this Job.
        :type: str
        """
        allowed_values = ["PLAN", "APPLY", "DESTROY", "IMPORT_TF_STATE"]
        if not value_allowed_none_or_none_sentinel(operation, allowed_values):
            operation = 'UNKNOWN_ENUM_VALUE'
        self._operation = operation

    @property
    def job_operation_details(self):
        """
        Gets the job_operation_details of this Job.

        :return: The job_operation_details of this Job.
        :rtype: oci.resource_manager.models.JobOperationDetails
        """
        return self._job_operation_details

    @job_operation_details.setter
    def job_operation_details(self, job_operation_details):
        """
        Sets the job_operation_details of this Job.

        :param job_operation_details: The job_operation_details of this Job.
        :type: oci.resource_manager.models.JobOperationDetails
        """
        self._job_operation_details = job_operation_details

    @property
    def apply_job_plan_resolution(self):
        """
        Gets the apply_job_plan_resolution of this Job.

        :return: The apply_job_plan_resolution of this Job.
        :rtype: oci.resource_manager.models.ApplyJobPlanResolution
        """
        return self._apply_job_plan_resolution

    @apply_job_plan_resolution.setter
    def apply_job_plan_resolution(self, apply_job_plan_resolution):
        """
        Sets the apply_job_plan_resolution of this Job.

        :param apply_job_plan_resolution: The apply_job_plan_resolution of this Job.
        :type: oci.resource_manager.models.ApplyJobPlanResolution
        """
        self._apply_job_plan_resolution = apply_job_plan_resolution

    @property
    def resolved_plan_job_id(self):
        """
        Gets the resolved_plan_job_id of this Job.
        Deprecated. Use the property `executionPlanJobId` in `jobOperationDetails` instead.
        The plan job `OCID`__ that was used (if this was an apply job and was not auto-approved).

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resolved_plan_job_id of this Job.
        :rtype: str
        """
        return self._resolved_plan_job_id

    @resolved_plan_job_id.setter
    def resolved_plan_job_id(self, resolved_plan_job_id):
        """
        Sets the resolved_plan_job_id of this Job.
        Deprecated. Use the property `executionPlanJobId` in `jobOperationDetails` instead.
        The plan job `OCID`__ that was used (if this was an apply job and was not auto-approved).

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resolved_plan_job_id: The resolved_plan_job_id of this Job.
        :type: str
        """
        self._resolved_plan_job_id = resolved_plan_job_id

    @property
    def time_created(self):
        """
        Gets the time_created of this Job.
        The date and time when the job was created.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :return: The time_created of this Job.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Job.
        The date and time when the job was created.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :param time_created: The time_created of this Job.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_finished(self):
        """
        Gets the time_finished of this Job.
        The date and time when the job stopped running, irrespective of whether the job ran successfully.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :return: The time_finished of this Job.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this Job.
        The date and time when the job stopped running, irrespective of whether the job ran successfully.
        Format is defined by RFC3339.
        Example: `2020-01-25T21:10:29.600Z`


        :param time_finished: The time_finished of this Job.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Job.
        Current state of the specified job.
        For more information about job lifecycle states in Resource Manager, see
        `Key Concepts`__.

        __ https://docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__JobStates

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Job.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Job.
        Current state of the specified job.
        For more information about job lifecycle states in Resource Manager, see
        `Key Concepts`__.

        __ https://docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/resourcemanager.htm#concepts__JobStates


        :param lifecycle_state: The lifecycle_state of this Job.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def failure_details(self):
        """
        Gets the failure_details of this Job.

        :return: The failure_details of this Job.
        :rtype: oci.resource_manager.models.FailureDetails
        """
        return self._failure_details

    @failure_details.setter
    def failure_details(self, failure_details):
        """
        Sets the failure_details of this Job.

        :param failure_details: The failure_details of this Job.
        :type: oci.resource_manager.models.FailureDetails
        """
        self._failure_details = failure_details

    @property
    def cancellation_details(self):
        """
        Gets the cancellation_details of this Job.

        :return: The cancellation_details of this Job.
        :rtype: oci.resource_manager.models.CancellationDetails
        """
        return self._cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, cancellation_details):
        """
        Sets the cancellation_details of this Job.

        :param cancellation_details: The cancellation_details of this Job.
        :type: oci.resource_manager.models.CancellationDetails
        """
        self._cancellation_details = cancellation_details

    @property
    def working_directory(self):
        """
        Gets the working_directory of this Job.
        File path to the directory from which Terraform runs.
        If not specified, the root directory is used.
        This parameter is ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.


        :return: The working_directory of this Job.
        :rtype: str
        """
        return self._working_directory

    @working_directory.setter
    def working_directory(self, working_directory):
        """
        Sets the working_directory of this Job.
        File path to the directory from which Terraform runs.
        If not specified, the root directory is used.
        This parameter is ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.


        :param working_directory: The working_directory of this Job.
        :type: str
        """
        self._working_directory = working_directory

    @property
    def variables(self):
        """
        Gets the variables of this Job.
        Terraform variables associated with this resource.
        Maximum number of variables supported is 250.
        The maximum size of each variable, including both name and value, is 8192 bytes.
        Example: `{\"CompartmentId\": \"compartment-id-value\"}`


        :return: The variables of this Job.
        :rtype: dict(str, str)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this Job.
        Terraform variables associated with this resource.
        Maximum number of variables supported is 250.
        The maximum size of each variable, including both name and value, is 8192 bytes.
        Example: `{\"CompartmentId\": \"compartment-id-value\"}`


        :param variables: The variables of this Job.
        :type: dict(str, str)
        """
        self._variables = variables

    @property
    def config_source(self):
        """
        Gets the config_source of this Job.

        :return: The config_source of this Job.
        :rtype: oci.resource_manager.models.ConfigSourceRecord
        """
        return self._config_source

    @config_source.setter
    def config_source(self, config_source):
        """
        Sets the config_source of this Job.

        :param config_source: The config_source of this Job.
        :type: oci.resource_manager.models.ConfigSourceRecord
        """
        self._config_source = config_source

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Job.
        Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Job.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Job.
        Free-form tags associated with this resource. Each tag is a key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Job.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Job.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Job.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Job.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Job.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_database_insight_details import UpdateDatabaseInsightDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateMacsManagedExternalDatabaseInsightDetails(UpdateDatabaseInsightDetails):
    """
    The information to be updated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateMacsManagedExternalDatabaseInsightDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.UpdateMacsManagedExternalDatabaseInsightDetails.entity_source` attribute
        of this class is ``MACS_MANAGED_EXTERNAL_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this UpdateMacsManagedExternalDatabaseInsightDetails.
            Allowed values for this property are: "AUTONOMOUS_DATABASE", "EM_MANAGED_EXTERNAL_DATABASE", "MACS_MANAGED_EXTERNAL_DATABASE"
        :type entity_source: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateMacsManagedExternalDatabaseInsightDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateMacsManagedExternalDatabaseInsightDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'entity_source': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._entity_source = None
        self._freeform_tags = None
        self._defined_tags = None
        self._entity_source = 'MACS_MANAGED_EXTERNAL_DATABASE'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAppCatalogSubscriptionDetails(object):
    """
    details for creating a subscription for a listing resource version.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAppCatalogSubscriptionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateAppCatalogSubscriptionDetails.
        :type compartment_id: str

        :param listing_id:
            The value to assign to the listing_id property of this CreateAppCatalogSubscriptionDetails.
        :type listing_id: str

        :param listing_resource_version:
            The value to assign to the listing_resource_version property of this CreateAppCatalogSubscriptionDetails.
        :type listing_resource_version: str

        :param oracle_terms_of_use_link:
            The value to assign to the oracle_terms_of_use_link property of this CreateAppCatalogSubscriptionDetails.
        :type oracle_terms_of_use_link: str

        :param eula_link:
            The value to assign to the eula_link property of this CreateAppCatalogSubscriptionDetails.
        :type eula_link: str

        :param time_retrieved:
            The value to assign to the time_retrieved property of this CreateAppCatalogSubscriptionDetails.
        :type time_retrieved: datetime

        :param signature:
            The value to assign to the signature property of this CreateAppCatalogSubscriptionDetails.
        :type signature: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'listing_id': 'str',
            'listing_resource_version': 'str',
            'oracle_terms_of_use_link': 'str',
            'eula_link': 'str',
            'time_retrieved': 'datetime',
            'signature': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'listing_id': 'listingId',
            'listing_resource_version': 'listingResourceVersion',
            'oracle_terms_of_use_link': 'oracleTermsOfUseLink',
            'eula_link': 'eulaLink',
            'time_retrieved': 'timeRetrieved',
            'signature': 'signature'
        }

        self._compartment_id = None
        self._listing_id = None
        self._listing_resource_version = None
        self._oracle_terms_of_use_link = None
        self._eula_link = None
        self._time_retrieved = None
        self._signature = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateAppCatalogSubscriptionDetails.
        The compartmentID for the subscription.


        :return: The compartment_id of this CreateAppCatalogSubscriptionDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateAppCatalogSubscriptionDetails.
        The compartmentID for the subscription.


        :param compartment_id: The compartment_id of this CreateAppCatalogSubscriptionDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def listing_id(self):
        """
        **[Required]** Gets the listing_id of this CreateAppCatalogSubscriptionDetails.
        The OCID of the listing.


        :return: The listing_id of this CreateAppCatalogSubscriptionDetails.
        :rtype: str
        """
        return self._listing_id

    @listing_id.setter
    def listing_id(self, listing_id):
        """
        Sets the listing_id of this CreateAppCatalogSubscriptionDetails.
        The OCID of the listing.


        :param listing_id: The listing_id of this CreateAppCatalogSubscriptionDetails.
        :type: str
        """
        self._listing_id = listing_id

    @property
    def listing_resource_version(self):
        """
        **[Required]** Gets the listing_resource_version of this CreateAppCatalogSubscriptionDetails.
        Listing resource version.


        :return: The listing_resource_version of this CreateAppCatalogSubscriptionDetails.
        :rtype: str
        """
        return self._listing_resource_version

    @listing_resource_version.setter
    def listing_resource_version(self, listing_resource_version):
        """
        Sets the listing_resource_version of this CreateAppCatalogSubscriptionDetails.
        Listing resource version.


        :param listing_resource_version: The listing_resource_version of this CreateAppCatalogSubscriptionDetails.
        :type: str
        """
        self._listing_resource_version = listing_resource_version

    @property
    def oracle_terms_of_use_link(self):
        """
        **[Required]** Gets the oracle_terms_of_use_link of this CreateAppCatalogSubscriptionDetails.
        Oracle TOU link


        :return: The oracle_terms_of_use_link of this CreateAppCatalogSubscriptionDetails.
        :rtype: str
        """
        return self._oracle_terms_of_use_link

    @oracle_terms_of_use_link.setter
    def oracle_terms_of_use_link(self, oracle_terms_of_use_link):
        """
        Sets the oracle_terms_of_use_link of this CreateAppCatalogSubscriptionDetails.
        Oracle TOU link


        :param oracle_terms_of_use_link: The oracle_terms_of_use_link of this CreateAppCatalogSubscriptionDetails.
        :type: str
        """
        self._oracle_terms_of_use_link = oracle_terms_of_use_link

    @property
    def eula_link(self):
        """
        Gets the eula_link of this CreateAppCatalogSubscriptionDetails.
        EULA link


        :return: The eula_link of this CreateAppCatalogSubscriptionDetails.
        :rtype: str
        """
        return self._eula_link

    @eula_link.setter
    def eula_link(self, eula_link):
        """
        Sets the eula_link of this CreateAppCatalogSubscriptionDetails.
        EULA link


        :param eula_link: The eula_link of this CreateAppCatalogSubscriptionDetails.
        :type: str
        """
        self._eula_link = eula_link

    @property
    def time_retrieved(self):
        """
        **[Required]** Gets the time_retrieved of this CreateAppCatalogSubscriptionDetails.
        Date and time the agreements were retrieved, in `RFC3339`__ format.
        Example: `2018-03-20T12:32:53.532Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_retrieved of this CreateAppCatalogSubscriptionDetails.
        :rtype: datetime
        """
        return self._time_retrieved

    @time_retrieved.setter
    def time_retrieved(self, time_retrieved):
        """
        Sets the time_retrieved of this CreateAppCatalogSubscriptionDetails.
        Date and time the agreements were retrieved, in `RFC3339`__ format.
        Example: `2018-03-20T12:32:53.532Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_retrieved: The time_retrieved of this CreateAppCatalogSubscriptionDetails.
        :type: datetime
        """
        self._time_retrieved = time_retrieved

    @property
    def signature(self):
        """
        **[Required]** Gets the signature of this CreateAppCatalogSubscriptionDetails.
        A generated signature for this listing resource version retrieved the agreements API.


        :return: The signature of this CreateAppCatalogSubscriptionDetails.
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """
        Sets the signature of this CreateAppCatalogSubscriptionDetails.
        A generated signature for this listing resource version retrieved the agreements API.


        :param signature: The signature of this CreateAppCatalogSubscriptionDetails.
        :type: str
        """
        self._signature = signature

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateIPSecConnectionTunnelDetails(object):
    """
    UpdateIPSecConnectionTunnelDetails model.
    """

    #: A constant which can be used with the routing property of a UpdateIPSecConnectionTunnelDetails.
    #: This constant has a value of "BGP"
    ROUTING_BGP = "BGP"

    #: A constant which can be used with the routing property of a UpdateIPSecConnectionTunnelDetails.
    #: This constant has a value of "STATIC"
    ROUTING_STATIC = "STATIC"

    #: A constant which can be used with the routing property of a UpdateIPSecConnectionTunnelDetails.
    #: This constant has a value of "POLICY"
    ROUTING_POLICY = "POLICY"

    #: A constant which can be used with the ike_version property of a UpdateIPSecConnectionTunnelDetails.
    #: This constant has a value of "V1"
    IKE_VERSION_V1 = "V1"

    #: A constant which can be used with the ike_version property of a UpdateIPSecConnectionTunnelDetails.
    #: This constant has a value of "V2"
    IKE_VERSION_V2 = "V2"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateIPSecConnectionTunnelDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateIPSecConnectionTunnelDetails.
        :type display_name: str

        :param routing:
            The value to assign to the routing property of this UpdateIPSecConnectionTunnelDetails.
            Allowed values for this property are: "BGP", "STATIC", "POLICY"
        :type routing: str

        :param ike_version:
            The value to assign to the ike_version property of this UpdateIPSecConnectionTunnelDetails.
            Allowed values for this property are: "V1", "V2"
        :type ike_version: str

        :param bgp_session_config:
            The value to assign to the bgp_session_config property of this UpdateIPSecConnectionTunnelDetails.
        :type bgp_session_config: oci.core.models.UpdateIPSecTunnelBgpSessionDetails

        :param encryption_domain_config:
            The value to assign to the encryption_domain_config property of this UpdateIPSecConnectionTunnelDetails.
        :type encryption_domain_config: oci.core.models.UpdateIPSecTunnelEncryptionDomainDetails

        """
        self.swagger_types = {
            'display_name': 'str',
            'routing': 'str',
            'ike_version': 'str',
            'bgp_session_config': 'UpdateIPSecTunnelBgpSessionDetails',
            'encryption_domain_config': 'UpdateIPSecTunnelEncryptionDomainDetails'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'routing': 'routing',
            'ike_version': 'ikeVersion',
            'bgp_session_config': 'bgpSessionConfig',
            'encryption_domain_config': 'encryptionDomainConfig'
        }

        self._display_name = None
        self._routing = None
        self._ike_version = None
        self._bgp_session_config = None
        self._encryption_domain_config = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateIPSecConnectionTunnelDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :return: The display_name of this UpdateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateIPSecConnectionTunnelDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid
        entering confidential information.


        :param display_name: The display_name of this UpdateIPSecConnectionTunnelDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def routing(self):
        """
        Gets the routing of this UpdateIPSecConnectionTunnelDetails.
        The type of routing to use for this tunnel (either BGP dynamic routing or static routing).

        Allowed values for this property are: "BGP", "STATIC", "POLICY"


        :return: The routing of this UpdateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._routing

    @routing.setter
    def routing(self, routing):
        """
        Sets the routing of this UpdateIPSecConnectionTunnelDetails.
        The type of routing to use for this tunnel (either BGP dynamic routing or static routing).


        :param routing: The routing of this UpdateIPSecConnectionTunnelDetails.
        :type: str
        """
        allowed_values = ["BGP", "STATIC", "POLICY"]
        if not value_allowed_none_or_none_sentinel(routing, allowed_values):
            raise ValueError(
                "Invalid value for `routing`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._routing = routing

    @property
    def ike_version(self):
        """
        Gets the ike_version of this UpdateIPSecConnectionTunnelDetails.
        Internet Key Exchange protocol version.

        Allowed values for this property are: "V1", "V2"


        :return: The ike_version of this UpdateIPSecConnectionTunnelDetails.
        :rtype: str
        """
        return self._ike_version

    @ike_version.setter
    def ike_version(self, ike_version):
        """
        Sets the ike_version of this UpdateIPSecConnectionTunnelDetails.
        Internet Key Exchange protocol version.


        :param ike_version: The ike_version of this UpdateIPSecConnectionTunnelDetails.
        :type: str
        """
        allowed_values = ["V1", "V2"]
        if not value_allowed_none_or_none_sentinel(ike_version, allowed_values):
            raise ValueError(
                "Invalid value for `ike_version`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._ike_version = ike_version

    @property
    def bgp_session_config(self):
        """
        Gets the bgp_session_config of this UpdateIPSecConnectionTunnelDetails.

        :return: The bgp_session_config of this UpdateIPSecConnectionTunnelDetails.
        :rtype: oci.core.models.UpdateIPSecTunnelBgpSessionDetails
        """
        return self._bgp_session_config

    @bgp_session_config.setter
    def bgp_session_config(self, bgp_session_config):
        """
        Sets the bgp_session_config of this UpdateIPSecConnectionTunnelDetails.

        :param bgp_session_config: The bgp_session_config of this UpdateIPSecConnectionTunnelDetails.
        :type: oci.core.models.UpdateIPSecTunnelBgpSessionDetails
        """
        self._bgp_session_config = bgp_session_config

    @property
    def encryption_domain_config(self):
        """
        Gets the encryption_domain_config of this UpdateIPSecConnectionTunnelDetails.

        :return: The encryption_domain_config of this UpdateIPSecConnectionTunnelDetails.
        :rtype: oci.core.models.UpdateIPSecTunnelEncryptionDomainDetails
        """
        return self._encryption_domain_config

    @encryption_domain_config.setter
    def encryption_domain_config(self, encryption_domain_config):
        """
        Sets the encryption_domain_config of this UpdateIPSecConnectionTunnelDetails.

        :param encryption_domain_config: The encryption_domain_config of this UpdateIPSecConnectionTunnelDetails.
        :type: oci.core.models.UpdateIPSecTunnelEncryptionDomainDetails
        """
        self._encryption_domain_config = encryption_domain_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_configuration_metric_group import DatabaseConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DBExternalInstance(DatabaseConfigurationMetricGroup):
    """
    Configuration parameters defined for external databases instance level.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DBExternalInstance object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.DBExternalInstance.metric_name` attribute
        of this class is ``DB_EXTERNAL_INSTANCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this DBExternalInstance.
            Allowed values for this property are: "DB_EXTERNAL_PROPERTIES", "DB_EXTERNAL_INSTANCE", "DB_OS_CONFIG_INSTANCE"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this DBExternalInstance.
        :type time_collected: datetime

        :param instance_name:
            The value to assign to the instance_name property of this DBExternalInstance.
        :type instance_name: str

        :param host_name:
            The value to assign to the host_name property of this DBExternalInstance.
        :type host_name: str

        :param cpu_count:
            The value to assign to the cpu_count property of this DBExternalInstance.
        :type cpu_count: int

        :param host_memory_capacity:
            The value to assign to the host_memory_capacity property of this DBExternalInstance.
        :type host_memory_capacity: float

        :param version:
            The value to assign to the version property of this DBExternalInstance.
        :type version: str

        :param parallel:
            The value to assign to the parallel property of this DBExternalInstance.
        :type parallel: str

        :param instance_role:
            The value to assign to the instance_role property of this DBExternalInstance.
        :type instance_role: str

        :param logins:
            The value to assign to the logins property of this DBExternalInstance.
        :type logins: str

        :param database_status:
            The value to assign to the database_status property of this DBExternalInstance.
        :type database_status: str

        :param status:
            The value to assign to the status property of this DBExternalInstance.
        :type status: str

        :param edition:
            The value to assign to the edition property of this DBExternalInstance.
        :type edition: str

        :param startup_time:
            The value to assign to the startup_time property of this DBExternalInstance.
        :type startup_time: datetime

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'instance_name': 'str',
            'host_name': 'str',
            'cpu_count': 'int',
            'host_memory_capacity': 'float',
            'version': 'str',
            'parallel': 'str',
            'instance_role': 'str',
            'logins': 'str',
            'database_status': 'str',
            'status': 'str',
            'edition': 'str',
            'startup_time': 'datetime'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'instance_name': 'instanceName',
            'host_name': 'hostName',
            'cpu_count': 'cpuCount',
            'host_memory_capacity': 'hostMemoryCapacity',
            'version': 'version',
            'parallel': 'parallel',
            'instance_role': 'instanceRole',
            'logins': 'logins',
            'database_status': 'databaseStatus',
            'status': 'status',
            'edition': 'edition',
            'startup_time': 'startupTime'
        }

        self._metric_name = None
        self._time_collected = None
        self._instance_name = None
        self._host_name = None
        self._cpu_count = None
        self._host_memory_capacity = None
        self._version = None
        self._parallel = None
        self._instance_role = None
        self._logins = None
        self._database_status = None
        self._status = None
        self._edition = None
        self._startup_time = None
        self._metric_name = 'DB_EXTERNAL_INSTANCE'

    @property
    def instance_name(self):
        """
        **[Required]** Gets the instance_name of this DBExternalInstance.
        Name of the database instance.


        :return: The instance_name of this DBExternalInstance.
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """
        Sets the instance_name of this DBExternalInstance.
        Name of the database instance.


        :param instance_name: The instance_name of this DBExternalInstance.
        :type: str
        """
        self._instance_name = instance_name

    @property
    def host_name(self):
        """
        **[Required]** Gets the host_name of this DBExternalInstance.
        Host name of the database instance.


        :return: The host_name of this DBExternalInstance.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this DBExternalInstance.
        Host name of the database instance.


        :param host_name: The host_name of this DBExternalInstance.
        :type: str
        """
        self._host_name = host_name

    @property
    def cpu_count(self):
        """
        Gets the cpu_count of this DBExternalInstance.
        Total number of CPUs allocated for the host.


        :return: The cpu_count of this DBExternalInstance.
        :rtype: int
        """
        return self._cpu_count

    @cpu_count.setter
    def cpu_count(self, cpu_count):
        """
        Sets the cpu_count of this DBExternalInstance.
        Total number of CPUs allocated for the host.


        :param cpu_count: The cpu_count of this DBExternalInstance.
        :type: int
        """
        self._cpu_count = cpu_count

    @property
    def host_memory_capacity(self):
        """
        Gets the host_memory_capacity of this DBExternalInstance.
        Total amount of usable Physical RAM Memory available in gigabytes.


        :return: The host_memory_capacity of this DBExternalInstance.
        :rtype: float
        """
        return self._host_memory_capacity

    @host_memory_capacity.setter
    def host_memory_capacity(self, host_memory_capacity):
        """
        Sets the host_memory_capacity of this DBExternalInstance.
        Total amount of usable Physical RAM Memory available in gigabytes.


        :param host_memory_capacity: The host_memory_capacity of this DBExternalInstance.
        :type: float
        """
        self._host_memory_capacity = host_memory_capacity

    @property
    def version(self):
        """
        Gets the version of this DBExternalInstance.
        Database version.


        :return: The version of this DBExternalInstance.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DBExternalInstance.
        Database version.


        :param version: The version of this DBExternalInstance.
        :type: str
        """
        self._version = version

    @property
    def parallel(self):
        """
        Gets the parallel of this DBExternalInstance.
        Indicates whether the instance is mounted in cluster database mode (YES) or not (NO).


        :return: The parallel of this DBExternalInstance.
        :rtype: str
        """
        return self._parallel

    @parallel.setter
    def parallel(self, parallel):
        """
        Sets the parallel of this DBExternalInstance.
        Indicates whether the instance is mounted in cluster database mode (YES) or not (NO).


        :param parallel: The parallel of this DBExternalInstance.
        :type: str
        """
        self._parallel = parallel

    @property
    def instance_role(self):
        """
        Gets the instance_role of this DBExternalInstance.
        Role (permissions) of the database instance.


        :return: The instance_role of this DBExternalInstance.
        :rtype: str
        """
        return self._instance_role

    @instance_role.setter
    def instance_role(self, instance_role):
        """
        Sets the instance_role of this DBExternalInstance.
        Role (permissions) of the database instance.


        :param instance_role: The instance_role of this DBExternalInstance.
        :type: str
        """
        self._instance_role = instance_role

    @property
    def logins(self):
        """
        Gets the logins of this DBExternalInstance.
        Indicates if logins are allowed or restricted.


        :return: The logins of this DBExternalInstance.
        :rtype: str
        """
        return self._logins

    @logins.setter
    def logins(self, logins):
        """
        Sets the logins of this DBExternalInstance.
        Indicates if logins are allowed or restricted.


        :param logins: The logins of this DBExternalInstance.
        :type: str
        """
        self._logins = logins

    @property
    def database_status(self):
        """
        Gets the database_status of this DBExternalInstance.
        Status of the database.


        :return: The database_status of this DBExternalInstance.
        :rtype: str
        """
        return self._database_status

    @database_status.setter
    def database_status(self, database_status):
        """
        Sets the database_status of this DBExternalInstance.
        Status of the database.


        :param database_status: The database_status of this DBExternalInstance.
        :type: str
        """
        self._database_status = database_status

    @property
    def status(self):
        """
        Gets the status of this DBExternalInstance.
        Status of the instance.


        :return: The status of this DBExternalInstance.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DBExternalInstance.
        Status of the instance.


        :param status: The status of this DBExternalInstance.
        :type: str
        """
        self._status = status

    @property
    def edition(self):
        """
        Gets the edition of this DBExternalInstance.
        The edition of the database.


        :return: The edition of this DBExternalInstance.
        :rtype: str
        """
        return self._edition

    @edition.setter
    def edition(self, edition):
        """
        Sets the edition of this DBExternalInstance.
        The edition of the database.


        :param edition: The edition of this DBExternalInstance.
        :type: str
        """
        self._edition = edition

    @property
    def startup_time(self):
        """
        Gets the startup_time of this DBExternalInstance.
        Start up time of the database instance.


        :return: The startup_time of this DBExternalInstance.
        :rtype: datetime
        """
        return self._startup_time

    @startup_time.setter
    def startup_time(self, startup_time):
        """
        Sets the startup_time of this DBExternalInstance.
        Start up time of the database instance.


        :param startup_time: The startup_time of this DBExternalInstance.
        :type: datetime
        """
        self._startup_time = startup_time

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostedEntitySummary(object):
    """
    Information about a hosted entity which includes identifier, name, and type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostedEntitySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_identifier:
            The value to assign to the entity_identifier property of this HostedEntitySummary.
        :type entity_identifier: str

        :param entity_name:
            The value to assign to the entity_name property of this HostedEntitySummary.
        :type entity_name: str

        :param entity_type:
            The value to assign to the entity_type property of this HostedEntitySummary.
        :type entity_type: str

        """
        self.swagger_types = {
            'entity_identifier': 'str',
            'entity_name': 'str',
            'entity_type': 'str'
        }

        self.attribute_map = {
            'entity_identifier': 'entityIdentifier',
            'entity_name': 'entityName',
            'entity_type': 'entityType'
        }

        self._entity_identifier = None
        self._entity_name = None
        self._entity_type = None

    @property
    def entity_identifier(self):
        """
        **[Required]** Gets the entity_identifier of this HostedEntitySummary.
        The identifier of the entity.


        :return: The entity_identifier of this HostedEntitySummary.
        :rtype: str
        """
        return self._entity_identifier

    @entity_identifier.setter
    def entity_identifier(self, entity_identifier):
        """
        Sets the entity_identifier of this HostedEntitySummary.
        The identifier of the entity.


        :param entity_identifier: The entity_identifier of this HostedEntitySummary.
        :type: str
        """
        self._entity_identifier = entity_identifier

    @property
    def entity_name(self):
        """
        **[Required]** Gets the entity_name of this HostedEntitySummary.
        The entity name.


        :return: The entity_name of this HostedEntitySummary.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this HostedEntitySummary.
        The entity name.


        :param entity_name: The entity_name of this HostedEntitySummary.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this HostedEntitySummary.
        The entity type.


        :return: The entity_type of this HostedEntitySummary.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this HostedEntitySummary.
        The entity type.


        :param entity_type: The entity_type of this HostedEntitySummary.
        :type: str
        """
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerImage(object):
    """
    Container image metadata.
    """

    #: A constant which can be used with the lifecycle_state property of a ContainerImage.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a ContainerImage.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ContainerImage.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerImage object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this ContainerImage.
        :type compartment_id: str

        :param created_by:
            The value to assign to the created_by property of this ContainerImage.
        :type created_by: str

        :param digest:
            The value to assign to the digest property of this ContainerImage.
        :type digest: str

        :param display_name:
            The value to assign to the display_name property of this ContainerImage.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ContainerImage.
        :type id: str

        :param layers:
            The value to assign to the layers property of this ContainerImage.
        :type layers: list[oci.artifacts.models.ContainerImageLayer]

        :param layers_size_in_bytes:
            The value to assign to the layers_size_in_bytes property of this ContainerImage.
        :type layers_size_in_bytes: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ContainerImage.
            Allowed values for this property are: "AVAILABLE", "DELETED", "DELETING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param manifest_size_in_bytes:
            The value to assign to the manifest_size_in_bytes property of this ContainerImage.
        :type manifest_size_in_bytes: int

        :param pull_count:
            The value to assign to the pull_count property of this ContainerImage.
        :type pull_count: int

        :param repository_id:
            The value to assign to the repository_id property of this ContainerImage.
        :type repository_id: str

        :param repository_name:
            The value to assign to the repository_name property of this ContainerImage.
        :type repository_name: str

        :param time_created:
            The value to assign to the time_created property of this ContainerImage.
        :type time_created: datetime

        :param time_last_pulled:
            The value to assign to the time_last_pulled property of this ContainerImage.
        :type time_last_pulled: datetime

        :param version:
            The value to assign to the version property of this ContainerImage.
        :type version: str

        :param versions:
            The value to assign to the versions property of this ContainerImage.
        :type versions: list[oci.artifacts.models.ContainerVersion]

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'created_by': 'str',
            'digest': 'str',
            'display_name': 'str',
            'id': 'str',
            'layers': 'list[ContainerImageLayer]',
            'layers_size_in_bytes': 'int',
            'lifecycle_state': 'str',
            'manifest_size_in_bytes': 'int',
            'pull_count': 'int',
            'repository_id': 'str',
            'repository_name': 'str',
            'time_created': 'datetime',
            'time_last_pulled': 'datetime',
            'version': 'str',
            'versions': 'list[ContainerVersion]'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'created_by': 'createdBy',
            'digest': 'digest',
            'display_name': 'displayName',
            'id': 'id',
            'layers': 'layers',
            'layers_size_in_bytes': 'layersSizeInBytes',
            'lifecycle_state': 'lifecycleState',
            'manifest_size_in_bytes': 'manifestSizeInBytes',
            'pull_count': 'pullCount',
            'repository_id': 'repositoryId',
            'repository_name': 'repositoryName',
            'time_created': 'timeCreated',
            'time_last_pulled': 'timeLastPulled',
            'version': 'version',
            'versions': 'versions'
        }

        self._compartment_id = None
        self._created_by = None
        self._digest = None
        self._display_name = None
        self._id = None
        self._layers = None
        self._layers_size_in_bytes = None
        self._lifecycle_state = None
        self._manifest_size_in_bytes = None
        self._pull_count = None
        self._repository_id = None
        self._repository_name = None
        self._time_created = None
        self._time_last_pulled = None
        self._version = None
        self._versions = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ContainerImage.
        The compartment OCID to which the container image belongs. Inferred from the container repository.


        :return: The compartment_id of this ContainerImage.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ContainerImage.
        The compartment OCID to which the container image belongs. Inferred from the container repository.


        :param compartment_id: The compartment_id of this ContainerImage.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def created_by(self):
        """
        **[Required]** Gets the created_by of this ContainerImage.
        The `OCID`__ of the user or principal that created the resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The created_by of this ContainerImage.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ContainerImage.
        The `OCID`__ of the user or principal that created the resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param created_by: The created_by of this ContainerImage.
        :type: str
        """
        self._created_by = created_by

    @property
    def digest(self):
        """
        **[Required]** Gets the digest of this ContainerImage.
        The container image digest.


        :return: The digest of this ContainerImage.
        :rtype: str
        """
        return self._digest

    @digest.setter
    def digest(self, digest):
        """
        Sets the digest of this ContainerImage.
        The container image digest.


        :param digest: The digest of this ContainerImage.
        :type: str
        """
        self._digest = digest

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ContainerImage.
        The repository name and the most recent version associated with the image.
        If there are no versions associated with the image, then last known version and digest are used instead.
        If the last known version is unavailable, then 'unknown' is used instead of the version.

        Example: `ubuntu:latest` or `ubuntu:latest@sha256:45b23dee08af5e43a7fea6c4cf9c25ccf269ee113168c19722f87876677c5cb2`


        :return: The display_name of this ContainerImage.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ContainerImage.
        The repository name and the most recent version associated with the image.
        If there are no versions associated with the image, then last known version and digest are used instead.
        If the last known version is unavailable, then 'unknown' is used instead of the version.

        Example: `ubuntu:latest` or `ubuntu:latest@sha256:45b23dee08af5e43a7fea6c4cf9c25ccf269ee113168c19722f87876677c5cb2`


        :param display_name: The display_name of this ContainerImage.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ContainerImage.
        The `OCID`__ of the container image.

        Example: `ocid1.containerimage.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this ContainerImage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContainerImage.
        The `OCID`__ of the container image.

        Example: `ocid1.containerimage.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this ContainerImage.
        :type: str
        """
        self._id = id

    @property
    def layers(self):
        """
        **[Required]** Gets the layers of this ContainerImage.
        Layers of which the image is composed, ordered by the layer digest.


        :return: The layers of this ContainerImage.
        :rtype: list[oci.artifacts.models.ContainerImageLayer]
        """
        return self._layers

    @layers.setter
    def layers(self, layers):
        """
        Sets the layers of this ContainerImage.
        Layers of which the image is composed, ordered by the layer digest.


        :param layers: The layers of this ContainerImage.
        :type: list[oci.artifacts.models.ContainerImageLayer]
        """
        self._layers = layers

    @property
    def layers_size_in_bytes(self):
        """
        **[Required]** Gets the layers_size_in_bytes of this ContainerImage.
        The total size of the container image layers in bytes.


        :return: The layers_size_in_bytes of this ContainerImage.
        :rtype: int
        """
        return self._layers_size_in_bytes

    @layers_size_in_bytes.setter
    def layers_size_in_bytes(self, layers_size_in_bytes):
        """
        Sets the layers_size_in_bytes of this ContainerImage.
        The total size of the container image layers in bytes.


        :param layers_size_in_bytes: The layers_size_in_bytes of this ContainerImage.
        :type: int
        """
        self._layers_size_in_bytes = layers_size_in_bytes

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ContainerImage.
        The current state of the container image.

        Allowed values for this property are: "AVAILABLE", "DELETED", "DELETING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ContainerImage.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ContainerImage.
        The current state of the container image.


        :param lifecycle_state: The lifecycle_state of this ContainerImage.
        :type: str
        """
        allowed_values = ["AVAILABLE", "DELETED", "DELETING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def manifest_size_in_bytes(self):
        """
        **[Required]** Gets the manifest_size_in_bytes of this ContainerImage.
        The size of the container image manifest in bytes.


        :return: The manifest_size_in_bytes of this ContainerImage.
        :rtype: int
        """
        return self._manifest_size_in_bytes

    @manifest_size_in_bytes.setter
    def manifest_size_in_bytes(self, manifest_size_in_bytes):
        """
        Sets the manifest_size_in_bytes of this ContainerImage.
        The size of the container image manifest in bytes.


        :param manifest_size_in_bytes: The manifest_size_in_bytes of this ContainerImage.
        :type: int
        """
        self._manifest_size_in_bytes = manifest_size_in_bytes

    @property
    def pull_count(self):
        """
        **[Required]** Gets the pull_count of this ContainerImage.
        Total number of pulls.


        :return: The pull_count of this ContainerImage.
        :rtype: int
        """
        return self._pull_count

    @pull_count.setter
    def pull_count(self, pull_count):
        """
        Sets the pull_count of this ContainerImage.
        Total number of pulls.


        :param pull_count: The pull_count of this ContainerImage.
        :type: int
        """
        self._pull_count = pull_count

    @property
    def repository_id(self):
        """
        **[Required]** Gets the repository_id of this ContainerImage.
        The `OCID`__ of the container repository.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The repository_id of this ContainerImage.
        :rtype: str
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """
        Sets the repository_id of this ContainerImage.
        The `OCID`__ of the container repository.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param repository_id: The repository_id of this ContainerImage.
        :type: str
        """
        self._repository_id = repository_id

    @property
    def repository_name(self):
        """
        **[Required]** Gets the repository_name of this ContainerImage.
        The container repository name.


        :return: The repository_name of this ContainerImage.
        :rtype: str
        """
        return self._repository_name

    @repository_name.setter
    def repository_name(self, repository_name):
        """
        Sets the repository_name of this ContainerImage.
        The container repository name.


        :param repository_name: The repository_name of this ContainerImage.
        :type: str
        """
        self._repository_name = repository_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ContainerImage.
        An RFC 3339 timestamp indicating when the image was created.


        :return: The time_created of this ContainerImage.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ContainerImage.
        An RFC 3339 timestamp indicating when the image was created.


        :param time_created: The time_created of this ContainerImage.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_pulled(self):
        """
        Gets the time_last_pulled of this ContainerImage.
        An RFC 3339 timestamp indicating when the image was last pulled.


        :return: The time_last_pulled of this ContainerImage.
        :rtype: datetime
        """
        return self._time_last_pulled

    @time_last_pulled.setter
    def time_last_pulled(self, time_last_pulled):
        """
        Sets the time_last_pulled of this ContainerImage.
        An RFC 3339 timestamp indicating when the image was last pulled.


        :param time_last_pulled: The time_last_pulled of this ContainerImage.
        :type: datetime
        """
        self._time_last_pulled = time_last_pulled

    @property
    def version(self):
        """
        Gets the version of this ContainerImage.
        The most recent version associated with this image.


        :return: The version of this ContainerImage.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ContainerImage.
        The most recent version associated with this image.


        :param version: The version of this ContainerImage.
        :type: str
        """
        self._version = version

    @property
    def versions(self):
        """
        **[Required]** Gets the versions of this ContainerImage.
        The versions associated with this image.


        :return: The versions of this ContainerImage.
        :rtype: list[oci.artifacts.models.ContainerVersion]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """
        Sets the versions of this ContainerImage.
        The versions associated with this image.


        :param versions: The versions of this ContainerImage.
        :type: list[oci.artifacts.models.ContainerVersion]
        """
        self._versions = versions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EstimateRecallDataSizeResult(object):
    """
    This is the size and time range of data to be recalled
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EstimateRecallDataSizeResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_data_ended:
            The value to assign to the time_data_ended property of this EstimateRecallDataSizeResult.
        :type time_data_ended: datetime

        :param time_data_started:
            The value to assign to the time_data_started property of this EstimateRecallDataSizeResult.
        :type time_data_started: datetime

        :param size_in_bytes:
            The value to assign to the size_in_bytes property of this EstimateRecallDataSizeResult.
        :type size_in_bytes: int

        :param is_overlapping_with_existing_recalls:
            The value to assign to the is_overlapping_with_existing_recalls property of this EstimateRecallDataSizeResult.
        :type is_overlapping_with_existing_recalls: bool

        """
        self.swagger_types = {
            'time_data_ended': 'datetime',
            'time_data_started': 'datetime',
            'size_in_bytes': 'int',
            'is_overlapping_with_existing_recalls': 'bool'
        }

        self.attribute_map = {
            'time_data_ended': 'timeDataEnded',
            'time_data_started': 'timeDataStarted',
            'size_in_bytes': 'sizeInBytes',
            'is_overlapping_with_existing_recalls': 'isOverlappingWithExistingRecalls'
        }

        self._time_data_ended = None
        self._time_data_started = None
        self._size_in_bytes = None
        self._is_overlapping_with_existing_recalls = None

    @property
    def time_data_ended(self):
        """
        **[Required]** Gets the time_data_ended of this EstimateRecallDataSizeResult.
        This is the end of the time range of data to be recalled.  timeDataStarted and timeDataEnded delineate
        the time range of the archived data to be recalled.  They may not be exact the same as the
        parameters in the request input (EstimateRecallDataSizeDetails).


        :return: The time_data_ended of this EstimateRecallDataSizeResult.
        :rtype: datetime
        """
        return self._time_data_ended

    @time_data_ended.setter
    def time_data_ended(self, time_data_ended):
        """
        Sets the time_data_ended of this EstimateRecallDataSizeResult.
        This is the end of the time range of data to be recalled.  timeDataStarted and timeDataEnded delineate
        the time range of the archived data to be recalled.  They may not be exact the same as the
        parameters in the request input (EstimateRecallDataSizeDetails).


        :param time_data_ended: The time_data_ended of this EstimateRecallDataSizeResult.
        :type: datetime
        """
        self._time_data_ended = time_data_ended

    @property
    def time_data_started(self):
        """
        **[Required]** Gets the time_data_started of this EstimateRecallDataSizeResult.
        This is the start of the time range of data to be recalled


        :return: The time_data_started of this EstimateRecallDataSizeResult.
        :rtype: datetime
        """
        return self._time_data_started

    @time_data_started.setter
    def time_data_started(self, time_data_started):
        """
        Sets the time_data_started of this EstimateRecallDataSizeResult.
        This is the start of the time range of data to be recalled


        :param time_data_started: The time_data_started of this EstimateRecallDataSizeResult.
        :type: datetime
        """
        self._time_data_started = time_data_started

    @property
    def size_in_bytes(self):
        """
        **[Required]** Gets the size_in_bytes of this EstimateRecallDataSizeResult.
        This is the size in bytes


        :return: The size_in_bytes of this EstimateRecallDataSizeResult.
        :rtype: int
        """
        return self._size_in_bytes

    @size_in_bytes.setter
    def size_in_bytes(self, size_in_bytes):
        """
        Sets the size_in_bytes of this EstimateRecallDataSizeResult.
        This is the size in bytes


        :param size_in_bytes: The size_in_bytes of this EstimateRecallDataSizeResult.
        :type: int
        """
        self._size_in_bytes = size_in_bytes

    @property
    def is_overlapping_with_existing_recalls(self):
        """
        Gets the is_overlapping_with_existing_recalls of this EstimateRecallDataSizeResult.
        This indicates if the time range of data to be recalled overlaps with existing recalled data


        :return: The is_overlapping_with_existing_recalls of this EstimateRecallDataSizeResult.
        :rtype: bool
        """
        return self._is_overlapping_with_existing_recalls

    @is_overlapping_with_existing_recalls.setter
    def is_overlapping_with_existing_recalls(self, is_overlapping_with_existing_recalls):
        """
        Sets the is_overlapping_with_existing_recalls of this EstimateRecallDataSizeResult.
        This indicates if the time range of data to be recalled overlaps with existing recalled data


        :param is_overlapping_with_existing_recalls: The is_overlapping_with_existing_recalls of this EstimateRecallDataSizeResult.
        :type: bool
        """
        self._is_overlapping_with_existing_recalls = is_overlapping_with_existing_recalls

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsConfigWorkRequest(object):
    """
    LogAnalyticsConfigWorkRequest
    """

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "CREATE_ASSOCIATIONS"
    OPERATION_TYPE_CREATE_ASSOCIATIONS = "CREATE_ASSOCIATIONS"

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "DELETE_ASSOCIATIONS"
    OPERATION_TYPE_DELETE_ASSOCIATIONS = "DELETE_ASSOCIATIONS"

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "APPEND_LOOKUP_DATA"
    OPERATION_TYPE_APPEND_LOOKUP_DATA = "APPEND_LOOKUP_DATA"

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "UPDATE_LOOKUP_DATA"
    OPERATION_TYPE_UPDATE_LOOKUP_DATA = "UPDATE_LOOKUP_DATA"

    #: A constant which can be used with the operation_type property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "DELETE_LOOKUP"
    OPERATION_TYPE_DELETE_LOOKUP = "DELETE_LOOKUP"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsConfigWorkRequest.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsConfigWorkRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this LogAnalyticsConfigWorkRequest.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsConfigWorkRequest.
        :type compartment_id: str

        :param operation_type:
            The value to assign to the operation_type property of this LogAnalyticsConfigWorkRequest.
            Allowed values for this property are: "CREATE_ASSOCIATIONS", "DELETE_ASSOCIATIONS", "APPEND_LOOKUP_DATA", "UPDATE_LOOKUP_DATA", "DELETE_LOOKUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operation_type: str

        :param payload:
            The value to assign to the payload property of this LogAnalyticsConfigWorkRequest.
        :type payload: list[oci.log_analytics.models.LogAnalyticsConfigWorkRequestPayload]

        :param percent_complete:
            The value to assign to the percent_complete property of this LogAnalyticsConfigWorkRequest.
        :type percent_complete: int

        :param time_started:
            The value to assign to the time_started property of this LogAnalyticsConfigWorkRequest.
        :type time_started: datetime

        :param time_accepted:
            The value to assign to the time_accepted property of this LogAnalyticsConfigWorkRequest.
        :type time_accepted: datetime

        :param time_finished:
            The value to assign to the time_finished property of this LogAnalyticsConfigWorkRequest.
        :type time_finished: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LogAnalyticsConfigWorkRequest.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'operation_type': 'str',
            'payload': 'list[LogAnalyticsConfigWorkRequestPayload]',
            'percent_complete': 'int',
            'time_started': 'datetime',
            'time_accepted': 'datetime',
            'time_finished': 'datetime',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'operation_type': 'operationType',
            'payload': 'payload',
            'percent_complete': 'percentComplete',
            'time_started': 'timeStarted',
            'time_accepted': 'timeAccepted',
            'time_finished': 'timeFinished',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._compartment_id = None
        self._operation_type = None
        self._payload = None
        self._percent_complete = None
        self._time_started = None
        self._time_accepted = None
        self._time_finished = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        Gets the id of this LogAnalyticsConfigWorkRequest.
        The workrequest unique identifier.


        :return: The id of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LogAnalyticsConfigWorkRequest.
        The workrequest unique identifier.


        :param id: The id of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this LogAnalyticsConfigWorkRequest.
        The compartment unique identifier.


        :return: The compartment_id of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsConfigWorkRequest.
        The compartment unique identifier.


        :param compartment_id: The compartment_id of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def operation_type(self):
        """
        Gets the operation_type of this LogAnalyticsConfigWorkRequest.
        The operation type.  There are two classes of operations, association operations and
        lookup operations.  Associations may be created or deleted, and lookup operations include
        append, update and delete.

        Allowed values for this property are: "CREATE_ASSOCIATIONS", "DELETE_ASSOCIATIONS", "APPEND_LOOKUP_DATA", "UPDATE_LOOKUP_DATA", "DELETE_LOOKUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operation_type of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._operation_type

    @operation_type.setter
    def operation_type(self, operation_type):
        """
        Sets the operation_type of this LogAnalyticsConfigWorkRequest.
        The operation type.  There are two classes of operations, association operations and
        lookup operations.  Associations may be created or deleted, and lookup operations include
        append, update and delete.


        :param operation_type: The operation_type of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        allowed_values = ["CREATE_ASSOCIATIONS", "DELETE_ASSOCIATIONS", "APPEND_LOOKUP_DATA", "UPDATE_LOOKUP_DATA", "DELETE_LOOKUP"]
        if not value_allowed_none_or_none_sentinel(operation_type, allowed_values):
            operation_type = 'UNKNOWN_ENUM_VALUE'
        self._operation_type = operation_type

    @property
    def payload(self):
        """
        Gets the payload of this LogAnalyticsConfigWorkRequest.
        The list of config work request responses.


        :return: The payload of this LogAnalyticsConfigWorkRequest.
        :rtype: list[oci.log_analytics.models.LogAnalyticsConfigWorkRequestPayload]
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """
        Sets the payload of this LogAnalyticsConfigWorkRequest.
        The list of config work request responses.


        :param payload: The payload of this LogAnalyticsConfigWorkRequest.
        :type: list[oci.log_analytics.models.LogAnalyticsConfigWorkRequestPayload]
        """
        self._payload = payload

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this LogAnalyticsConfigWorkRequest.
        The completion percentage.


        :return: The percent_complete of this LogAnalyticsConfigWorkRequest.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this LogAnalyticsConfigWorkRequest.
        The completion percentage.


        :param percent_complete: The percent_complete of this LogAnalyticsConfigWorkRequest.
        :type: int
        """
        self._percent_complete = percent_complete

    @property
    def time_started(self):
        """
        Gets the time_started of this LogAnalyticsConfigWorkRequest.
        The time at which the work request was started.


        :return: The time_started of this LogAnalyticsConfigWorkRequest.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this LogAnalyticsConfigWorkRequest.
        The time at which the work request was started.


        :param time_started: The time_started of this LogAnalyticsConfigWorkRequest.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_accepted(self):
        """
        Gets the time_accepted of this LogAnalyticsConfigWorkRequest.
        The time at which the work request was accepted.


        :return: The time_accepted of this LogAnalyticsConfigWorkRequest.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this LogAnalyticsConfigWorkRequest.
        The time at which the work request was accepted.


        :param time_accepted: The time_accepted of this LogAnalyticsConfigWorkRequest.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_finished(self):
        """
        Gets the time_finished of this LogAnalyticsConfigWorkRequest.
        The time at which the work request was finished.


        :return: The time_finished of this LogAnalyticsConfigWorkRequest.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this LogAnalyticsConfigWorkRequest.
        The time at which the work request was finished.


        :param time_finished: The time_finished of this LogAnalyticsConfigWorkRequest.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this LogAnalyticsConfigWorkRequest.
        The lifecycle status.  Valid values are ACCEPTED, IN_PROGRESS, SUCCEEDED
        or FAILED

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LogAnalyticsConfigWorkRequest.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LogAnalyticsConfigWorkRequest.
        The lifecycle status.  Valid values are ACCEPTED, IN_PROGRESS, SUCCEEDED
        or FAILED


        :param lifecycle_state: The lifecycle_state of this LogAnalyticsConfigWorkRequest.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HealthCheckResult(object):
    """
    Information about a single backend server health check result reported by a network load balancer.
    """

    #: A constant which can be used with the health_check_status property of a HealthCheckResult.
    #: This constant has a value of "OK"
    HEALTH_CHECK_STATUS_OK = "OK"

    #: A constant which can be used with the health_check_status property of a HealthCheckResult.
    #: This constant has a value of "INVALID_STATUS_CODE"
    HEALTH_CHECK_STATUS_INVALID_STATUS_CODE = "INVALID_STATUS_CODE"

    #: A constant which can be used with the health_check_status property of a HealthCheckResult.
    #: This constant has a value of "TIMED_OUT"
    HEALTH_CHECK_STATUS_TIMED_OUT = "TIMED_OUT"

    #: A constant which can be used with the health_check_status property of a HealthCheckResult.
    #: This constant has a value of "HEALTH_PAYLOAD_MISMATCH"
    HEALTH_CHECK_STATUS_HEALTH_PAYLOAD_MISMATCH = "HEALTH_PAYLOAD_MISMATCH"

    #: A constant which can be used with the health_check_status property of a HealthCheckResult.
    #: This constant has a value of "CONNECT_FAILED"
    HEALTH_CHECK_STATUS_CONNECT_FAILED = "CONNECT_FAILED"

    #: A constant which can be used with the health_check_status property of a HealthCheckResult.
    #: This constant has a value of "UNKNOWN"
    HEALTH_CHECK_STATUS_UNKNOWN = "UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new HealthCheckResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param timestamp:
            The value to assign to the timestamp property of this HealthCheckResult.
        :type timestamp: datetime

        :param health_check_status:
            The value to assign to the health_check_status property of this HealthCheckResult.
            Allowed values for this property are: "OK", "INVALID_STATUS_CODE", "TIMED_OUT", "HEALTH_PAYLOAD_MISMATCH", "CONNECT_FAILED", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type health_check_status: str

        """
        self.swagger_types = {
            'timestamp': 'datetime',
            'health_check_status': 'str'
        }

        self.attribute_map = {
            'timestamp': 'timestamp',
            'health_check_status': 'healthCheckStatus'
        }

        self._timestamp = None
        self._health_check_status = None

    @property
    def timestamp(self):
        """
        **[Required]** Gets the timestamp of this HealthCheckResult.
        The date and time the data was retrieved, in the format defined by RFC3339.

        Example: `2020-05-01T18:28:11+00:00`


        :return: The timestamp of this HealthCheckResult.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this HealthCheckResult.
        The date and time the data was retrieved, in the format defined by RFC3339.

        Example: `2020-05-01T18:28:11+00:00`


        :param timestamp: The timestamp of this HealthCheckResult.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def health_check_status(self):
        """
        **[Required]** Gets the health_check_status of this HealthCheckResult.
        The result of the most recent health check.

        Allowed values for this property are: "OK", "INVALID_STATUS_CODE", "TIMED_OUT", "HEALTH_PAYLOAD_MISMATCH", "CONNECT_FAILED", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The health_check_status of this HealthCheckResult.
        :rtype: str
        """
        return self._health_check_status

    @health_check_status.setter
    def health_check_status(self, health_check_status):
        """
        Sets the health_check_status of this HealthCheckResult.
        The result of the most recent health check.


        :param health_check_status: The health_check_status of this HealthCheckResult.
        :type: str
        """
        allowed_values = ["OK", "INVALID_STATUS_CODE", "TIMED_OUT", "HEALTH_PAYLOAD_MISMATCH", "CONNECT_FAILED", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(health_check_status, allowed_values):
            health_check_status = 'UNKNOWN_ENUM_VALUE'
        self._health_check_status = health_check_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2014 Adam Knight
# Original Work: Copyright (c) 2012 Adam T. Lindsay (original author)

"""
Module to assist in verifying a signed header.
"""
from oci._vendor import six

from cryptography.hazmat.backends import default_backend  # noqa: 401
from cryptography.hazmat.primitives import hashes, hmac, serialization  # noqa: 401
from cryptography.hazmat.primitives.asymmetric import rsa, padding  # noqa: 401
from cryptography.exceptions import InvalidSignature  # noqa: 401

from base64 import b64decode

from .sign import Signer
from .utils import *  # noqa: 403


class Verifier(Signer):
    """
    Verifies signed text against a secret.
    For HMAC, the secret is the shared secret.
    For RSA, the secret is the PUBLIC key.
    """
    def _verify(self, data, signature):
        """
        Verifies the data matches a signed version with the given signature.
        `data` is the message to verify
        `signature` is a base64-encoded signature to verify against `data`
        """

        if isinstance(data, six.string_types):
            data = data.encode("ascii")
        if isinstance(signature, six.string_types):
            signature = signature.encode("ascii")

        if self.sign_algorithm == 'rsa':
            try:
                self._rsa_public.verify(
                    b64decode(signature),
                    data,
                    padding.PKCS1v15(),
                    self._rsahash()
                )
                return True
            except InvalidSignature:
                return False
        elif self.sign_algorithm == 'hmac':
            h = self._sign_hmac(data)
            s = b64decode(signature)
            return (h == s)
        else:
            raise HttpSigException("Unsupported algorithm.")  # noqa: 405


class HeaderVerifier(Verifier):
    """
    Verifies an HTTP signature from given headers.
    """
    def __init__(self, headers, secret, required_headers=None, method=None, path=None, host=None):
        """
        Instantiate a HeaderVerifier object.

        :param headers:             A dictionary of headers from the HTTP request.
        :param secret:              The HMAC secret or RSA *public* key.
        :param required_headers:    Optional. A list of headers required to be present to validate, even if the signature is otherwise valid.  Defaults to ['date'].
        :param method:              Optional. The HTTP method used in the request (eg. "GET"). Required for the '(request-target)' header.
        :param path:                Optional. The HTTP path requested, exactly as sent (including query arguments and fragments). Required for the '(request-target)' header.
        :param host:                Optional. The value to use for the Host header, if not supplied in :param:headers.
        """
        required_headers = required_headers or ['date']

        auth = parse_authorization_header(headers['authorization'])  # noqa: 405
        if len(auth) == 2:
            self.auth_dict = auth[1]
        else:
            raise HttpSigException("Invalid authorization header.")  # noqa: 405

        self.headers = CaseInsensitiveDict(headers)  # noqa: 405
        self.required_headers = [s.lower() for s in required_headers]
        self.method = method
        self.path = path
        self.host = host

        super(HeaderVerifier, self).__init__(secret, algorithm=self.auth_dict['algorithm'])

    def verify(self):
        """
        Verify the headers based on the arguments passed at creation and current properties.

        Raises an Exception if a required header (:param:required_headers) is not found in the signature.
        Returns True or False.
        """
        auth_headers = self.auth_dict.get('headers', 'date').split(' ')

        if len(set(self.required_headers) - set(auth_headers)) > 0:
            raise Exception('{} is a required header(s)'.format(', '.join(set(self.required_headers) - set(auth_headers))))

        signing_str = generate_message(auth_headers, self.headers, self.host, self.method, self.path)  # noqa: 405

        return self._verify(signing_str, self.auth_dict['signature'])
